#
# spec file for package php-xdebug
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    xdebug

%define flavor php7%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %(%{__php_config} --ini-dir)
%endif

Name:           %{php_name}-%{pkg_name}
%if "%{flavor}" == "php8" || "%{flavor}" == "php81"
Version:        3.2.0
%else
Version:        3.1.6
%endif
Release:        bp155.2.3.1
Summary:        Extended PHP debugger
License:        PHP-3.0
Group:          Productivity/Networking/Web/Servers
URL:            https://xdebug.org
Source0:        https://xdebug.org/files/%{pkg_name}-3.2.0.tgz
Source1:        https://xdebug.org/files/%{pkg_name}-3.1.6.tgz
Source10:       php-%{pkg_name}-rpmlintrc
BuildRequires:  %{php_name}-devel
BuildRequires:  %{php_name}-soap
BuildRequires:  autoconf
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}

%description
The Xdebug extension helps debugging scripts by providing
debug information such as:

  * stack and function traces in error messages with:
    o full parameter display for user defined functions
    o function name, file name and line indications
    o support for member functions
  * memory allocation
  * protection for infinite recursions

Xdebug also provides:

  * profiling information for PHP scripts
  * code coverage analysis
  * capabilities to debug your scripts interactively with a debug client

%prep
%if "%{flavor}" == "php8" || "%{flavor}" == "php81"
%setup -q -n %{pkg_name}-%{version}
%else
%setup -q -n %{pkg_name}-%{version} -T -b 1
%endif

%build
export CFLAGS="%{optflags} -fvisibility=hidden"
%{__phpize}
%configure --enable-xdebug
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
zend_extension = %{pkg_name}.so
EOF

%check
# check if the extension can be loaded
%{__php} --no-php-ini --define zend_extension=%{buildroot}%{php_extdir}/%{pkg_name}.so \
    --modules | grep Xdebug

%files
%license LICENSE
%doc CREDITS
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Tue Dec 12 2023 pgajdos@suse.com
- add php81 multibuild target
- modified sources
  %% _multibuild
* Sun Dec 11 2022 Arjen de Korte <suse+build@de-korte.org>
- Restore php7 build for targets that still have it
  %% _multibuild
* Thu Dec  8 2022 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.2.0
  * Fixed issue #1819: Allow a list of headers in
    'xdebug.client_discovery_header'
  * Fixed issue #2079: Add pseudo hosts xdebug://gateway and
    xdebug://nameserver
  * Fixed issue #2086: Include return value in return breakpoint
    interruption response
  * Fixed issue #2087: Introduce step for the return state and virtual
    property for return value
  * Fixed issue #2062: Xdebug now records whether systemd's PrivateTmp
    is used in its diagnostics information
  * Fixed issue #2104: Add support for PHP 8.2 "SensitiveParameter"
    attribute
  * Fixed issue #2117: Removed emulated properties for closures, as PHP
    8.2 adds debug information for them
  * Fixed issue #2122: Local variables are now available when
    using start_upon_error
  * Fixed issue #2123: Add warning in log and diagnositics information
    when a breakpoint is set on a non-existing file
  * Fixed issue #2138: Step debugger now disconnects and continues
    running the script, when the debugging client closes the connection
  * Fixed issue #2136: Duplicate line/conditional breakpoints are now
    rejected
  * Fixed issue #2014: Drop support for PHP 7.2
  * Fixed issue #2102: Drop support for PHP 7.3
  * Fixed issue #2103: Drop support for PHP 7.4
  * Fixed issue #2002: xdebug_trace_handler_t handler members are not
    always checked for NULL when executing
  * Fixed issue #2045: Inapproriate frowny face
  * Fixed issue #2089: Alpine Linux does not support res_ninit
  * Fixed issue #2093: Fatal error: linux/rtnetlink.h: No such file or
    directory linux/rtnetlink.h
  * Fixed issue #2098: With breakpoint_include_return_value enabled
    step_out break at every function
  * Fixed issue #2105: 3.2.0alpha1 package misses the php-header.h file
  * Fixed issue #2108: Segfault on PHP8.1 with PHPUnit 10 when path
    coverage is enabled
  * Fixed issue #2113: Crash at step_into after thrown exception with
    return value debugging en
  * Fixed issue #2121: Xdebug does not use local independent
    float-to-string functions
  * Fixed issue #2124: Xdebug incorrectly reports that there are no
    children for static closure properties, even though there are
  * Fixed issue #2125: Crash with PHP 8.2 on 32-bit due to change in
    "not set" value with CATCH opcode
  * Fixed issue #2126: Problems with retrieving global variables
  * Fixed issue #2127: Tracing does not handle NUL char in anonymous
    closure scope
  * Fixed issue #2133: Warning with regards to extra NUL character in
    xdebug_setcookie call
  * Fixed issue #2134: Xdebug stops at the line where the exception is
    created, not where it is thrown
  * Fixed issue #2135: Xdebug stops twice at the same line after a call
    breakpoint or xdebug_break()
- Updated to Xdebug 3.1.6
  * Fixed issue #2100: "Fatal error: debuginfo() must return an array"
    when Exception is thrown from debugInfo in PHP 8.x
  * Fixed issue #2101: When a temporary breakpoint is hit,
    breakpoint_list should show it as disabled
  * Fixed issue #2129: Cannot read snapshot Gzip-compressed data is
    corrupt
* Thu Dec  8 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove build target for php7 (PHP 7.4 reached EOL 28 Nov 2022)
  %% _multibuild
* Sun Jun 12 2022 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.1.5
  * Fixed bug #2056: Install documentation gives wrong arch for
    installation on M1 Macs
  * Fixed bug #2082: phpize --clean removes required clocks.m4 file
  * Fixed bug #2083: Constant defined with an enum case produce double
    "facet" attribute in context_get response
  * Fixed bug #2085: Crash when used with source guardian encoded files
  * Fixed bug #2090: Segfault in __callStatic() after FFI initialization
* Tue Apr 12 2022 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.1.4
  * Fixed issue #2006: Removing second call breakpoint with same
    function name
  * Fixed issue #2060: XDebug breaks the Symfony "PhpFilesAdapter"
    cache adapter
  * Fixed issue #2061: Possible use after free with GC Stats
  * Fixed issue #2063: Can't inspect ArrayObject storage elements
  * Fixed issue #2064: Segmentation fault in symfony cache
  * Fixed issue #2068: Debug session can be started with
    "XDEBUG_SESSION_START=anything" when xdebug.trigger_value is set
  * Fixed issue #2069: Warn when profiler_append is used together
    with zlib compression
  * Fixed issue #2075: Code coverage misses static array assignment
    lines
* Mon Feb 14 2022 Илья Индиго <ilya@ilya.pp.ua>
- Updated to Xdebug 3.1.3
  * Fixed issue #2049: evaling broken code (still) causes unhandled
    exception in PHP 7.4.
  * Fixed issue #2052: Memory leak when a trace file can't be
    opened because xdebug.trace_output_name is invalid.
  * Fixed issue #2054: Slowdown when calling a function with long
    string parameters.
  * Fixed issue #2055: Debugger creates XML with double facet attribute.
* Fri Dec 10 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.1.2
  * Fixed issue #2036: Segfault on fiber switch in finally block in
    garbage collected fiber
  * Fixed issue #2037: Crash when profile file can not be created
  * Fixed issue #2041: __debugInfo is not used for var_dump output
  * Fixed issue #2046: Segault on xdebug_get_function_stack inside a
    Fiber
* Tue Nov  9 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.1.1
  * Fixed issue #2016: apache gives no output with xdebug 3.1.0b2
    installed
  * Fixed issue #2024: Apache restarts in a loop under PHP 8.1.0 RC3
  * Fixed issue #2029: incorrect and inaccurate date and time displayed
    in xdebug.log and trace files
  * Fixed issue #2030: PhpStorm step-debug not working on PHP 8.0.11
  * Fixed issue #2032: Use runtime PHP version in DBGp and info pages
    instead of compiled-against version
  * Fixed issue #2034: Xdebug throws a Segmentation fault when
    'set_time_limit' function is disabled
  * Fixed issue #2035: Xdebug block everything with localhost in XAMMP
- Updated to 3.1.0
  * Fixed issue #1472: Add assignments to computer readable trace
    format
  * Fixed issue #1537: Add links to documentation to various different
    "features" after wizard has run
  * Fixed issue #1738: Add xdebug_notify() function to send data
    through DBGp to a debugging client
  * Fixed issue #1853: Enable profile compression for cachegrind files
  * Fixed issue #1890: Add connected client and protocol features to
    diagnostic page
  * Fixed issue #1898: API for querying the currently active mode(s)
  * Fixed issue #1933: Allow for cloud ID to be set through the
    trigger
  * Fixed issue #1938: Branches in traits aren’t marked as executed
  * Fixed issue #1948: Do not redirect warning and error messages to
    PHP's error log if an Xdebug log is active
  * Fixed issue #1949: private properties for internal classes can't
    be fetched for debugging
  * Fixed issue #1963: php exit code = -1073741819 when
    xdebug.mode = off (Windows Thread Safe Only)
  * Fixed issue #1969: Provide breakpoint ID / info in DBGp run
    command responses
  * Fixed issue #1970: xdebug_get_function_stack with unnamed
    (internal) parameters have wrong index
  * Fixed issue #1972: Add support for PHP 8.1 Fibers
  * Fixed issue #1974: Add gzip support to trace files
  * Fixed issue #1976: Switch debug session cookie to Lax, and remove
    expiry time
  * Fixed issue #1978: Xdebug's log messages are cut off at 512 bytes
  * Fixed issue #1980: PHP 8.1: Mark enum classes as "enum"
  * Fixed issue #1986: Add support for multiple trigger values
  * Fixed issue #1989: Profiling does not output correct class when
    parent keyword is used
  * Fixed issue #1992: Code Coverage with filter produces Segmentation
    fault on xdebug_stop_code_coverage()
  * Fixed issue #1993: eval-ing broken code causes stepping to break
  * Fixed issue #1996: Add support for Closure visualisation in traces,
    debugging, and Xdebug's var_dump
  * Fixed issue #1997: Added xdebug_connect_to_client() to attempt a
    debugging connect while running code
  * Fixed issue #1998: Double facet attribute generated for enums that
    are stored in properties
  * Fixed issue #1999: Add "readonly" facet to PHP 8.1 readonly
    properties
  * Fixed issue #2001: Add 'xdebug.use_compression' setting to turn
    on/off compression for profiling files
  * Fixed issue #2004: Figure out what "XDEBUG_SHOW_FNAME_TODO" define
    is for
  * Fixed issue #2007: xdebug 3.x fails to build on OS X 10.11 or
    earlier due to clock_gettime_nsec_np requirement
  * Fixed issue #2008: Using the XDEBUG_SESSION cookie could bypass
    shared-secret checks
  * Fixed issue #2009: xdebug_stop_code_coverage's argument has type
    mismatch
  * Fixed issue #2011: Closures as protected properties have double
    facet XML attribute
  * Fixed issue #2013: Support PHP 8.1
  * Fixed issue #2018: zlib compression support on Windows
  * Fixed issue #2019: Xdebug crash because of uninitialized memory
  * Fixed issue #2020: segfault if xdebug.dump.GET=* and integer key
    without value in URL
  * Fixed issue #2021: Segmentation fault due to NULL bytes in internal
    anonymous class names
  * Fixed issue #2025: Anonymous classes which extend are not detected
    as anonymous classes since PHP 8.0
* Fri Jul  2 2021 Arjen de Korte <suse+build@de-korte.org>
- Xdebug should be loaded as a zend_extension (not as extension)
* Thu Apr  8 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.0.4
  * Fixed issue #1802: Improve xdebug.org home page
  * Fixed issue #1944: tracing is started without trigger, when profiler
    is also enabled
  * Fixed issue #1947: xdebug_info() settings section does not show the
    modes that are overridden by XDEBUG_MODE
  * Fixed issue #1950: Assignment trace with ASSIGN_OBJ_REF crashes
  * Fixed issue #1954: Calling xdebug_start_trace without mode including
    tracing results in a fatal error
* Mon Feb 22 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.0.3
  * Fixed bug #1930: No local variables with trigger and xdebug_break()
  * Fixed bug #1931: xdebug_info() output misses configuration settings
    if phpinfo() has been called
  * Fixed bug #1932: One line in multi-line string concatenation is not
    covered
  * Fixed bug #1940: Wrong type used for showing GC Stats reports
- Xdebug can not be tested with 'make test'
* Tue Feb 16 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
* Sat Jan 16 2021 Arjen de Korte <suse+build@de-korte.org>
- Use php-config to determine location of files in package
* Mon Jan  4 2021 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.0.2
  * Fixed issue #1907: Empty exception message when setting the $message
    property to a stringable object
  * Fixed issue #1910: Code coverage misses constructor property
    promotion code
  * Fixed issue #1914: Compillation failure on OpenBSD
  * Fixed issue #1915: Debugger should only start with XDEBUG_SESSION and
    not XDEBUG_PROFILE
  * Fixed issue #1918: Warn if PHP's Garbage Collection is disabled in
    gc_stats mode
  * Fixed issue #1919: Crash when enabling filter without the right mode
    active
  * Fixed issue #1921: Xdebug does not start step debugging if
    start_with_request=trigger
  * Fixed issue #1922: Code coverage misses array assignment lines
  * Fixed issue #1924: Deprecated INI settings displayed in phpinfo()
  * Fixed issue #1925: xdebug.start_with_request and start_upon_error
    display inconsistent values
  * Fixed issue #1926: Add Xdebug mode's source to xdebug_info() output
  * Fixed issue #1927: Crash when calling xdebug_stop_trace without a
    trace in progress
  * Fixed issue #1928: xdebug_stop_gcstats() can also return false
* Fri Dec  4 2020 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.0.1
  * Fixed issue #1893: Crash with ext-fiber and xdebug.mode=coverage
  * Fixed issue #1896: Segfault with closures that are not created from
    user code
  * Fixed issue #1897: Crash when removing a breakpoint
  * Fixed issue #1900: Update README and add run-xdebug-tests.php to package
  * Fixed issue #1901: Stack traces are shown (with a broken time) when
    Xdebug's mode includes 'debug' but not 'develop' or 'trace'
  * Fixed issue #1902: Compillation failure on AIX
  * Fixed issue #1903: Constants should always be available, regardless of
    which mode Xdebug is in
  * Fixed issue #1904: Profile and trace files using %%t or %%u do not get the
    right names
  * Fixed issue #1905: Debugger does not disable request timeouts
* Wed Nov 25 2020 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 3.0.0
  * Xdebug 3 includes major changes in functionality compared to Xdebug 2.
    The primary way how you turn on functionality is through the new
    xdebug.mode PHP configuration setting. This made it possible to
    massively increase performance in many of Xdebug's sub systems as
    Xdebug is now much more conservative in which hooks are enabled.
    Configuration changes, massive performance improvements, and PHP 8
    support are the primary features in Xdebug 3, but there is much more.
    The upgrade guide lists the changes in great detail, please read it:
    https://xdebug.org/docs/upgrade_guide
* Mon Sep 28 2020 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 2.9.8
  * Fixed issue #1851: Paths are not counted as coveraged with loops calling function
  * Fixed issue #1855: Build issues on FreeBSD
* Wed Sep 16 2020 Arjen de Korte <suse+build@de-korte.org>
- Updated to Xdebug 2.9.7
  * Fixed issue #1839: Add keepalive options to debugging socket
- Updated to Xdebug 2.9.6
  * Fixed issue #1782: Cookie "XDEBUG_SESSION" will be soon rejected because it has
    the “sameSite” attribute set to none
  * Fixed issue #1787: Branch coverage data does not always follow the lines/functions
    format
  * Fixed issue #1790: Segfault in var_dump() or while debugging with protobuf extension
* Wed May  6 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to Xdebug 2.9.5
  * Fixed issue #1772: Crash with exception thrown inside a destructor
  * Fixed issue #1775: Segfault when another extension compiles a PHP file during RINIT
  * Fixed issue #1779: Nested multi-line built-in function in namespace are not covered
* Tue Apr 14 2020 munix9@googlemail.com
- Updated to Xdebug 2.9.4
  * Fixed issue #1763: Crash while setting opcode overrides in ZTS mode.
  * Fixed issue #1766: Using the DBGp detach command disables remote debugging for the whole process.
- Updated to Xdebug 2.9.3
  * Fixed issue #1753: Resolved breakpoints use information from wrong files
  * Fixed issue #1758: Xdebug changes error_get_last results inside a try catch
  * Fixed issue #1759: User registered opcode handlers should call ones already set by other extensions
- Updated to Xdebug 2.9.2
  * Fixed issue #1735: DBGp eval warning promoted to Exception can cause out-of-sync responses
  * Fixed issue #1736: Segmentation fault when other extensions run PHP in RINIT
  * Fixed issue #1739: Tracing footer not written
- Updated to Xdebug 2.9.1
  * Fixed issue #1721: Header may not contain NUL bytes in Unknown on line 0
  * Fixed issue #1727: Debugger stops more often than expected due to resolving breakpoints
  * Fixed issue #1728: INIT_STATIC_METHOD_CALL is not overloaded
  * Fixed issue #1731: var_dump with DateTime does not output properties (Ryan Mauger)
  * Fixed issue #1733: SEND_VAR_NO_REF_EX opcode, used for require(), is not overloaded
  * Fixed issue #1734: Segfault with DBGp "source" with a out-of-range start line number
* Tue Dec 24 2019 munix9@googlemail.com
- fix enabling extension in xdebug.ini
* Fri Dec 20 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to Xdebug 2.9.0
  * Improvements: #1723: Class/function pre-analysis for code coverage speed improvements
  * Removed feature: #1301: Removed aggregated profiler feature
  * Removed feature: #1720: Remove superfluous xdebug.remote_handler setting
  * Fixed bug #1722: Build warning issues on FreeBSD
  * Fixed bug #1724: Missing property types and uninitialised values in variable dumping routines
* Thu Nov 28 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to Xdebug 2.8.0
  * Fixed issue #1665: Segfault with garbage collection and complex function arguments
  * Fixed issue #1699: Crash during debugging Phalcon project
  * Fixed issue #1705: Crash while debugging with ionCube being used
  * Fixed issue #1708: Crash on evaluating object with properties
  * Fixed issue #1709: Wrong data type breaks tests on Big Endian build
  * Fixed issue #1713: INIT_FCALL is not overloaded in code coverage
* Tue May  7 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to Xdebug 2.7.2
  * Fixed #1488: Rewrite DBGp 'property_set' to always use eval
  * Fixed #1586: error_reporting()'s return value is incorrect during debugger's 'eval' command
  * Fixed #1615: Turn off Zend OPcache when remote debugger is turned on
  * Fixed #1656: remote_connect_back alters header if multiple values are present
  * Fixed #1662: __debugInfo should not be used for user-defined classes
- Updated to Xdebug 2.7.1
  * Fixed #1646: Missing newline in error message
  * Fixed #1647: Memory corruption when a conditional breakpoint is used
  * Fixed #1641: Perfomance degradation with getpid syscall
* Wed Mar  6 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to Xdebug 2.7.0
- adds support for PHP 7.3
- support for single step debugging of forked PHP worker processes
- fixes numerous memory leaks and bugs
- fixes of incompatibilities with Zend Opcache
- Fixes in 2.7.0:
  * Fixed bug #1520: Xdebug does not handle variables and properties
    with "-" in their name
  * Fixed bug #1577: Code coverage path analysis with chained catch
    fails in PHP 7.3
  * Fixed bug #1639: Compile warning/error on GCC 8 or Clang due
    to "break intentionally missing"
  * Fixed bug #1642: Debugger gives: "Warning: Header may not
    contain NUL bytes"
- Fixes in RC1:
  * Fixed bug #1551: Property with value null is not represented well
  * Fixed bug #1621: Xdebug fails to compile cleanly on 32-bit platforms
  * Fixed bug #1625: Work around ABI conflicts in PHP 7.3.0/PHP 7.3.1
  * Fixed bug #1628: The PHP function name being constructed to record
    when GC Collection runs, is not freed
  * Fixed bug #1629: SOAP Client/Server detection code does not handle
    inherited classes
- Fixes in RC1:
  * Fixed bug #1571: File/line information is not shown for closures
    in namespaces.
  * Fixed bug #1578: Compile error due to redefinition of "zif_handler"
    with old GCCs.
  * Fixed bug #1583: Xdebug crashes when OPcache's compact literals
    optimisation is on.
  * Fixed bug #1598: Make path/branch coverage work with OPcache loaded
    for PHP 7.3 and later.
  * Fixed bug #1620: Division by zero when GC Stats Collection runs with
    memory manager disabled.
* Wed Jan 23 2019 jweberhofer@weberhofer.at
- Changed package version to 2.7.0~beta1 to ensure correct updates
* Wed Jan 23 2019 suse+build@de-korte.org
- Removed redundant xdebug.ini source file
* Thu Dec 27 2018 suse+build@de-korte.org
- Updated to Xdebug 2.7.0beta1
  * Fixed issue #1519: PHP 7.3 support
- Updated to Xdebug 2.7.0alpha1
  * Fixed issue #938: Support remote debugging for PHP scripts that
    fork. (Sponsored by Brad Wilson)
  * Fixed issue #1487: Re-enable IPv6 test on Travis.
  * Fixed issue #1526: Namespace filter does equality match instead
    of prefix match.
  * Fixed issue #1532: SIGABRT when using remote debugging and an
    error is thrown in eval().
  * Fixed issue #1543: Various memory leaks due to changes in
    (internal) string handling.
* Wed Jan 31 2018 jweberhofer@weberhofer.at
- Compile with -fvisibility=hidden
- Updated to Xdebug 2.6.0
  https://xdebug.org/updates.php#x_2_6_0
  * support for profiling memory usage
  * configurable formatting of filenames
  * statistics of PHP's Garbage Collector
  * "remote" debugger:
  - "Notice" and "Warning" notifications are sent to the IDE
  - support for low-ASCII characters in property names and array keys
  - support for NULL characters in variable and property names
  - configurable connection timeouts
  * Many improvements and bug-fixes
* Sun Jan 14 2018 jweberhofer@weberhofer.at
- Updated to Xdebug 2.6.0beta1
  * Added filter support for tracing, stack traces and code coverage
  * Add X-Profile-File-Name header when a profile file has been generated.
  * Check whether variables tracing also works with =&.
  * Xdebug var dump tries casting properties.
  * SEND_REF lines are not marked as covered.
* Thu Dec 28 2017 jengelh@inai.de
- Restore previously sanitized description.
* Tue Dec 26 2017 jweberhofer@weberhofer.at
- Cleaned up spec file
- Support for PHP 7.2
- Updated to Xdebug 2.6.0alpha1
  * ChangeLog https://pecl.php.net/package-changelog.php?package=xdebug&release=2.6.0alpha1
  * Added features
  - Added "memory" output to profiling files, to find out where memory is allocated.
  - Dump super globals contents to error log upon errors, just like when this would happen for stack traces.
  - Parse X-Forwarded-For for the first IP address when selecting the remote_connect_back host.
  - Add DBGp: notifications for notices and warnings to be shown in IDEs.
  - Implement extended_properties feature to remote debugging to support names and values with low ASCII values.
  - Added xdebug.filename_format setting to configure the formatting of filenames when tracing.
  - Added support for Unix domain sockets to xdebug.remote_host.
  - Added xdebug_is_debugger_active() that returns true when debugger is connected.
  - Added support for earlier stack frames through new argument for xdebug_call_* functions.
  - Handle PHP 7.2's new methods for switch/case
  - Added xdebug.remote_timeout to make connect timeout configurable.
  - Make var_dump() also use the new xdebug.filename_format when formatting filenames.
  * Improvements
  - Added support for "%%s" specifier for xdebug.trace_output_name.
  - Improved error message in case the connection breaks.
  - Change DBGp tests to use TEST_PHP_EXECUTABLE instead of hard coded 'php'
  - Use FD_CLOEXEC with debugging sockets to prevent FDs from leaking to forked processes.
  - Improve the foldexpr in xt.vim to fold lines correctly.
  * Fixed bugs
  - property_get doesn't return @attributes for SimpleXMLElement.
  - Property names with quotes can not be fetch while debugging.
  - Fix "use after free" with in add_name_attribute_or_element.
  - Fixed memory leak with xdebug_path_info_dtor.
  - Debugging breaks with array element keys containing low-ASCII variables.
  - Tracing crashes with return_assignments and ternairy operator.
  - Crashes due to variable resolving/reading mechanism not taking care of temporary hash tables correctly (Nikita Popov, Derick).
  - Fixed s390x and ppc64 builds (Remi Collet).
  - Crash on ZEND_SWITCH_LONG / ZEND_SWITCH_STRING with more than 32 cases.
  * Changes
  - Use Error (Throwable) instead of fatal error when maximum nesting level is reached.
* Wed Aug  2 2017 tchvatal@suse.com
- Drop the php5 subpackage as we are removing php5 language
* Wed Jun 28 2017 jengelh@inai.de
- Trim some redundant pharse parts from the description.
* Tue Jun 27 2017 jweberhofer@weberhofer.at
- Updated to Xdebug 2.5.5
  Fixed bugs
  * #1439: TYPE_CHECK needs overloading due to smart branches
  * #1444: Code Coverage misses a variable in a multi-line function call
  * #1446: Code Coverage misses elseif if it uses an isset with a property
* Mon May 15 2017 jweberhofer@weberhofer.at
- Updated to Xdebug 2.5.4
  Fixed bugs
  * #799: Function traces report base class instead of object name
  * #1421: Fix set_time_limit hanging on PHP 5.6 when pcntl_exec does not exist (Frode E. Moe)
  * #1429: Code coverage does not cover null coalesce
  * #1434: Code coverage segfaults on 32-bit arch
- Updated to Xdebug 2.5.3
  Fixed bug
  * #1421: Xdebug crashes when it is loaded without pcntl being present
- Updated to Xdebug 2.5.2
  fixed bugs
  * #701: Functions as array indexes show ??? in trace
  * #1403: Code coverage does not cover BIND_STATIC
  * #1404: Execution time is calculated incorrectly
  * #1413: Code coverage mishap with PHP 7.1.3
  * #1414: Missing variable assignment in traces with OPcache loaded
  * #1415: Crash with multiple catch constructs with OPcache loaded
  * #1416: Trace files should not include the first result
    of a generator if it hasn't started yet
  * #1417: Fetching properties of static class contexts fails due
    to incorrect fetch mode
  * #1419: Summary not written when script ended with "pcntl_exec()"
* Tue Apr 18 2017 jweberhofer@weberhofer.at
- License is in fact a PHP 3.0 license; productnames and author has
  been changed to match the xdebug product.
* Thu Mar 30 2017 jweberhofer@weberhofer.at
- Clearified license
* Fri Mar 17 2017 jweberhofer@weberhofer.at
- Updated to Xdebug 2.5.1
  Fixes:
  * #1057: Add xdebug.ini of all settings to package
  * #1165: DBGp: step_out skips subsequent function calls
  * #1180: Code coverage crashes with non-standard start/stops
  * #1278: Xdebug with PHP 7 does not handle prefill-from-oparray
    for XDEBUG_CC_UNUSED
  * #1300: Xdebug functions are not exposing their signature to Reflection
  * #1313: Arguments to __call() trampoline picked from the wrong memory
    location
  * #1329: While printing out a stack with and function parameters,
    XDebug reads uninitialized zvals or free()d memory
  * #1381: Code Coverage misses line due to missing FETCH_DIM_W overload
  * #1385: can not fetch IS_INDIRECT properties
  * #1386: Executable code not shown as executed/executable
  * #1392: Unable to compile on FreeBSD due to missing struct definition
  * #1394: Code coverage does not cover instanceof (in elseif)
* Sun Jan 29 2017 jweberhofer@weberhofer.at
- Provide php-xdebug as a parallel installation of php5 and php7 is not possible
* Tue Dec 13 2016 jweberhofer@weberhofer.at
- Updated to Xdebug 2.5.0
  Support for PHP versions lower than PHP 5.5 has been dropped
  Improvements:
  * #1232: add memory delta to HTML traces
  * #1365: Allow remote_connect_back to be set through XDEBUG_CONFIG
  * #998: Added support for IPv6 (Thomas Vanhaniemi)
  * #1297: Initial PHP 7.1 support
  Fixes:
  * #1168: Added defensive check to prevent infinite loop
  * #1242: Xdebug on Windows with Eclipse has issues with breakpoint IDs
  * #1343: Wrong values of numerical keys outside 32bit range
  * #1357: Function signature using variadics is reported as being not executed
  * #1361: Remote debugging connection issues with Windows (Anatol Belski)
  * #1373: Crash in zend_hash_apply_with_arguments when debugging, due to unset symbol table
  * #1295: Apache crashes (SIGSEGV) when trying to establish connection when sockfd is large
  * #1303: POLLRDHUP is not supported outside of Gnu/Linux
  * #1331: Segfault in code coverage
- Updated to Xdebug 2.4.1
  Fixes:
  * #1106: A thrown Exception after a class with __debugInfo gives 2 errors
  * #1241: FAST_CALL/FAST_RET take #2
  * #1246: Path and branch coverage should be initialised per request, not globally
  * #1263: Code coverage segmentation fault with opcache enabled
  * #1277: Crash when using a userland function from RSHUTDOWN with profiling enabled
  * #1282: var_dump() of integers > 32 bit is broken on Windows
  * #1288: Segfault when uncaught exception message does not contain " in "
  * #1291: Debugclient installation fails on Mac OS X
  * #1326: Tracing and generators crashes with PHP 7.x.
  * #1333: Profiler accesses memory structures after freeing
* Tue Mar  8 2016 danimo@owncloud.com
- XDebug 2.4.0, ported to php7
* Fri Jan 29 2016 pgajdos@suse.com
- provides php-xdebug symbol
* Tue Jan 12 2016 pgajdos@suse.com
- remove _service
* Thu Jul  2 2015 cobexer@gmail.com
- reference the upstream xdebug.ini file directly using the package version
* Wed Jul  1 2015 jweberhofer@weberhofer.at
- Update to Xdebug 2.3.3
- Fixed bugs
  * #1130: Escaping issues with docrefs and HTML characters in error messages
  * #1133: PDO exception code value type is changed
  * #1137: Windows does not support %%zu formatting for sprintf
  * #1140: Tracing with __debugInfo() crashes Xdebug due to a stack overflow
  * #1148: Can't disable max_nesting_function
  * #1151: Crash when another extension calls call_user_function() during RINIT
  * Fixed crash with code coverage (Antony Dovgal)
  * Fixed usage of virtual_file_ex and STR_FREE (Remi Collet)
  * Reset overloaded opcodes at the end of each request (Eran Ifrah)
- Improvements
  * #686: Not possible to inspect SplObjectStorage instances with Xdebug
  * #864: No attributes are shown if an object extends ArrayIterator
  * #996: Can't evaluate property of class that extends ArrayObject
  * #1134: Allow introspection of ArrayObject implementation's internal storage
  * Get rid of setlocale hack, by using %%F instead of %%f (and speed up tracing
  * by 15-20%%)
* Mon Jun  8 2015 jweberhofer@weberhofer.at
- Use version specific ini file instead of master's.
* Mon Jun  1 2015 jweberhofer@weberhofer.at
- Included upstream xdebug.ini file
- Update to Xdebug 2.3.2
  * Fixed bug #1117: Path/branch coverage sometimes crashes
  * Fixed bug #1121: Segfaults with path/branch coverage
- Xdebug 2.3.1
  * Fixed bug #1112: Setting an invalid xdebug.trace_format causes Xdebug to
    crash
  * Fixed bug #1113: xdebug.*_trigger do no longer work, due to NULL not being
    an empty string
- Xdebug 2.3.0
  * Fixed bug #932: Added an error message in case the remote debug log
    couldn't be opened
  * Fixed bug #982: Incorrect file paths in exception stack trace
  * Fixed bug #1094: Segmentation fault when attempting to use branch/path
    coverage
  * Fixed bug #1101: Debugger is not triggered on xdebug_break() in JIT mode
  * Fixed bug #1102: Stop Xdebug from crashing when debugging PHP Code with
    "php -r".
  * Fixed bug #1103: XDEBUG_SESSION_STOP_NO_EXEC only stops first script
    executed with auto_prepend|append_files
  * Fixed bug #1104: One character non-public properties cause issues with
    debugging
  * Fixed bug #1105: Setting properties without specifying a type only works in
    topmost frame (Dominik del Bondio)
  * Fixed bug #1095: Crash when using a non-associate array key in GLOBALS
  * Fixed bug #1111: eval does not work when debugger is stopped in
    xdebug_throw_exception_hook (Dominik del Bondio)
  Added features
  * Implemented bug #304: File name and line number info for overloaded
    var_dump()
  * Implemented bug #310: Allow class vars and array keys with
    xdebug_debug_zval()
  * Implemented bug #722: Add stack trace limit setting.
  * Implemented bug #1003: Add option to xdebug_print_function_stack() to
    suppress filename and line number
  * Implemented bug #1004: Ability to halt on warning/notice
  * Implemented bug #1015: Added the xdebug.force_display_errors and
    xdebug.force_error_reporting php.ini-only settings to always override PHP's
    settings for display_errors and error_reporting
  * Implemented bug #1023: Add support for PHP 5.6 variadics
  * Implemented bug #1024: Add support for PHP 5.6's ASSIGN_POW
  Debugging
  * Implemented bug #406: Added support for remote debugging user-defined
    constants
  * Implemented bug #495: Added support for the wildcard exception name '*'
  * Implemented bug #1066: Better error message for SELinux preventing
    debugging connections
  * Implemented bug #1084: Added support for extended classes to trigger
    exception breakpoints
  * Implemented bug #1084: Added exception code as extra element to debugger
    XML
  Tracing
  * Implemented bug #341: Added the time index and memory usage for function
    returns in normal tracefiles
  * Implemented bug #644: Shared secret for profiler_enable_trigger and
    trace_enable_trigger with *_value option
  * Implemented bug #971: Added the trace file option
    "XDEBUG_TRACE_NAKED_FILENAME" to xdebug_start_trace() to prevent the ".xt"
    extension from being added
  * Implemented bug #1021: Added support for return values to computerized
    trace files
  * Implemented bug #1022: Added support for serialized variables as format in
    trace files in the form of option "5" for "xdebug.collect_params" Code
    Coverage
  * Implemented bug #380: Added xdebug_code_coverage_started()
  * Implemented bug #1034: Add collected path and branch information to
    xdebug_get_code_coverage() output
  Profiling
  * Implement bug #1054: Support for filename and function name compression in
    cachegrind files
  Changes
  * Implemented bug #863: Support xdebug.overload_var_dump through ini_set()
  * Implemented bug #973: Use case-insensitive filename comparison on all
    systems (Galen Wright-Watson)
  * Implemented bug #1057: Removed trailing whitespace from example xdebug.ini
  * Implemented bug #1096: Improve performance improvement for handling
    breakpoints by ignoring locales (Daniel Sloof)
  * Implemented bug #1100: Raise default max_nesting_level to 256
  Removed features
  * Support for PHP versions lower than PHP 5.4 have been dropped.
* Wed Feb 18 2015 jweberhofer@weberhofer.at
  xdebug is working with PHP 5.6 now.
- Update to 2.2.7
  * Fixed bug #1083: Segfault when requesting a variable for a context that did
    not have them.
  * Fixed bug #1087: zend_execute_script or zend_eval_string in RINIT
    segfaults.
  * Fixed bug #1088: Xdebug won't show dead and not executed lines at the
    second time.
  * Fixed bug #1098: Xdebug doesn't make use of __debugInfo.
  * Fixed segfaults with ZTS on PHP 5.6.
- Update to 2.2.6
  * Fixed bug #1048: Can not get $GLOBAL variable by property_value on function
    context.
  * Fixed bug #1073 and bug #1075: Segmentation fault with internal functions
    calling internal functions.
  * Fixed bug #1085: Fixed the tracefile analyser as the format version had
    been bumbed.
  * Fixed memory leaks.
- Check checksum on download
- Simplified / reformatted spec
* Fri Aug 29 2014 cobexer@gmail.com
- Update to 2.2.5
  * Added support for PHP 5.5.
  * multiple bugfixes
    for details see http://xdebug.org/updates.php#x_2_2_5
* Tue May 14 2013 adaugherity@tamu.edu
- Update to 2.2.2
  * support for PHP 5.5b1 (and 5.4)
* Tue Mar 29 2011 crrodriguez@opensuse.org
- Update to 2.1.1 final
* Fri Mar 25 2011 crrodriguez@opensuse.org
- Update to 2.1.1 RC1
* Fri Dec 24 2010 cristian.rodriguez@opensuse.org
- add a service
* Fri Dec 24 2010 cristian.rodriguez@opensuse.org
- Update to version 2.1.0 final
* Tue Apr  6 2010 crrodriguez@opensuse.org
- fix build in older products
* Fri Apr  2 2010 crrodriguez@opensuse.org
- update to version 2.1.0beta3
* Sun Sep 27 2009 crrodriguez@suse.de
- workaround for http://bugs.php.net/bug.php?id=49677
* Mon Nov 12 2007 crrodriguez@suse.de
- version 2.0.2
- Fixed bug #325: DBGP: "detach" stops further sessions being established
  from Apache.
- Fixed bug #321: Code coverage crashes on empty PHP files.
- Fixed bug #318: Segmentation Fault in code coverage analysis.
- Fixed bug #315: Xdebug crashes when including a file that doesn't exist.
- Fixed bug #314: PHP CLI Error Logging thwarted when XDebug Loaded.
- Fixed bug #300: Direction of var_dump().
- Always set the transaction_id and command. (Related to bug #313).
* Mon Oct 22 2007 crrodriguez@suse.de
- update to version 2.0.1
- Improved code coverage performance dramatically.
- PHP 5.3 compatibility (no namespaces yet though).
- Fixed bug #300: Xdebug does not force LTR rendering for its tables.
- Fixed bug #299: Computerized traces don't have a newline for return
  entries if memory limit is not enabled.
- Fixed bug #298: xdebug_var_dump() doesn't handle entity replacements
  correctly concerning string length.
- Fixed a memory free error related to remote debugging conditions.
* Thu May 17 2007 judas_iscariote@shorewall.net
- update snapshot to RC5-dev
* Sun Apr 29 2007 judas_iscariote@shorewall.net
- update to RC4 snapshot to fix some annoying crashes and bugs.
